@@ -6,15 +6,17 @@ import requests
 def get_data(data_set):
 
    extension = '.csv'
-   dir_name =  'https://raw.githubusercontent.com/aimluae/uaedata/tree/main/datasets'
+   dir_name =  'https://raw.githubusercontent.com/aimluae/uaedata/main/datasets/'
    filename = dir_name + data_set + extension
 
    if requests.get(filename).status_code == 200:
-      return pd.read_csv(filename)
+      df = pd.read_csv(filename)
+      return print(df.head())
    else:
       extension = '.xlsx'
       filename = dir_name + data_set + extension
-      return pd.read_excel(filename)
+      df = pd.read_excel(filename)
+      return print(df.head())
 
 def list_datasets():
    data_sets = [
@@ -22,4 +24,7 @@ def list_datasets():
       'customs_warehouses', 'declaration_cargo_detail-1', 'declaration_cargo_detail-2', 'Graduates_in_Highe_ Education_20-06-09',
       'livebirths', 'Services-En_0', 'vehicle_clearance_certificate', 'UAE_National_Red List_Species',
    ]
-   return data_sets
\ No newline at end of file
+   return data_sets
+
+
+get_data('customs_warehouse_licensees')
\ No newline at end of file
